Hyphenation patterns for English to be used by hyphen.
These data objects are not really intended to be used directly, but rather to be consulted
by the hyphen() function without further user interaction.
Usage
hyph.en
Arguments
Format
The pattern slot of each hyphenation pattern object has three colums:
orig
The original pattern in patgen style format.
char
Only the character elements of the pattern which can be matched to parts of an actual word.
nums
A code of digits defining the possibility to split syllables at respective places in this pattern.
References
Liang, F.M. (1983). Word Hy-phen-a-tion by Com-put-er.
Dissertation, Stanford University, Dept. of Computer Science.