This function adds support for English to the sylly package. You should not
need to call it manually, as that is done automatically when this package is
loaded.
Usage
hyph.support.en()
Arguments
Details
In particular,
a new set of hyphenation patterns is being added (see hyph.en).
To use the patterns with hyphen, simply use the abbreviation: